"""Core functionality for hagents package."""

def hello(name="World"):
    """
    A simple greeting function.
    
    Args:
        name (str): Name to greet
        
    Returns:
        str: Greeting message
    """
    return f"Hello, {name}! Welcome to hagents!"

def get_version():
    """
    Get the current version of the package.
    
    Returns:
        str: Package version
    """
    from . import __version__
    return __version__

# Example class
class SimpleAgent:
    """A simple agent class for demonstration."""
    
    def __init__(self, name="Agent"):
        self.name = name
    
    def introduce(self):
        """Introduce the agent."""
        return f"I am {self.name}, a simple agent from hagents package."