"""hagents - A simple Python package for demonstration purposes."""

__version__ = "0.1.0"
__author__ = "Your Name"
__email__ = "your.email@example.com"

# Package imports
from .core import hello

# Package metadata
__all__ = ["hello", "__version__"]