from setuptools import setup, find_packages

setup(
    name="hagents",
    version="0.1.0",
    description="A simple Python package for demonstration purposes",
    long_description=open("README.md").read(),
    long_description_content_type="text/markdown",
    author="Jervis",
    url="https://github.com/IHEII/hagents",
    packages=find_packages(),
    classifiers=[
        "Development Status :: 3 - Alpha",
        "Intended Audience :: Developers",
        "License :: OSI Approved :: MIT License",
        "Programming Language :: Python :: 3",
        "Programming Language :: Python :: 3.10",
        "Programming Language :: Python :: 3.11",
        "Programming Language :: Python :: 3.12",
    ],
    python_requires=">=3.10",
    install_requires=[],
)